## Ansible Queries List
This page contains all queries from Ansible.
### AWS
Bellow are listed queries related with Ansible AWS:



|            Query             |Severity|Category|Description|Help|
|------------------------------|--------|--------|-----------|----|
|ECS Service Admin Role is Present<br/><sup><sub>7db727c1-1720-468e-b80e-06697f71e09e</sub></sup>|<span style="color:#C00">High</span>|Access Control|ECS Services must not have Admin roles, which means the attribute 'role' must not be an admin role|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ecs_service_module.html">Documentation</a><br/>|
|S3 Bucket Allows Get Action From All Principals<br/><sup><sub>53bce6a8-5492-4b1b-81cf-664385f0c4bf</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets must not allow Get Action From All Principals, as to prevent leaking private information to the entire internet or allow unauthorized data tampering / deletion. This means the 'Effect' must not be 'Allow' when the 'Action' is Get, for all Principals.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html">Documentation</a><br/>|
|S3 Bucket Allows WriteACP Action From All Principals<br/><sup><sub>7529b8d2-55d7-44d2-b1cd-d7d2984a2a81</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets must not allow Write_ACP Action From All Principals, as to prevent leaking private information to the entire internet or allow unauthorized data tampering / deletion. This means the 'Effect' must not be 'Allow' when the 'Action' is Write_ACP, for all Principals.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html">Documentation</a><br/>|
|S3 Bucket With All Permissions<br/><sup><sub>6a6d7e56-c913-4549-b5c5-5221e624d2ec</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets must not have all permissions, as to prevent leaking private information to the entire internet or allow unauthorized data tampering / deletion. This means the 'Effect' must not be 'Allow' when the 'Action' is '*', for all Principals.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html#parameter-policy">Documentation</a><br/>|
|IAM Policies With Full Privileges<br/><sup><sub>e401d614-8026-4f4b-9af9-75d1197461ba</sub></sup>|<span style="color:#C00">High</span>|Access Control|IAM policies shouldn't allow full administrative privileges (for all resources)|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_managed_policy_module.html">Documentation</a><br/>|
|S3 Bucket ACL Allows Read to Any Authenticated User<br/><sup><sub>75480b31-f349-4b9a-861f-bce19588e674</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets should not be readable to any authenticated user|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/aws_s3_module.html#parameter-permission">Documentation</a><br/>|
|IAM Policy Grants Full Permissions<br/><sup><sub>b5ed026d-a772-4f07-97f9-664ba0b116f8</sub></sup>|<span style="color:#C00">High</span>|Access Control|Check if an IAM policy is granting full permissions to resources from the get-go, instead of granting permissions gradually as necessary.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_managed_policy_module.html">Documentation</a><br/>|
|SNS Topic is Publicly Accessible<br/><sup><sub>905f4741-f965-45c1-98db-f7a00a0e5c73</sub></sup>|<span style="color:#C00">High</span>|Access Control|SNS Topic Policy should not allow any principal to access|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/sns_topic_module.html">Documentation</a><br/>|
|S3 Bucket ACL Allows Read to All Users<br/><sup><sub>a1ef9d2e-4163-40cb-bd92-04f0d602a15d</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets should not be readable to all users|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/aws_s3_module.html#parameter-permission">Documentation</a><br/>|
|S3 Bucket Allows Put Action From All Principals<br/><sup><sub>a0f1bfe0-741e-473f-b3b2-13e66f856fab</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets must not allow Put Action From All Principals, as to prevent leaking private information to the entire internet or allow unauthorized data tampering / deletion. This means the 'Effect' must not be 'Allow' when the 'Action' is Put, for all Principals.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html">Documentation</a><br/>|
|SQS Queue Exposed<br/><sup><sub>86b0efa7-4901-4edd-a37a-c034bec6645a</sub></sup>|<span style="color:#C00">High</span>|Access Control|Checks if the SQS Queue is exposed|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/sqs_queue_module.html#parameter-policy">Documentation</a><br/>|
|S3 Bucket Allows Delete Action From All Principals<br/><sup><sub>6fa44721-ef21-41c6-8665-330d59461163</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets must not allow Delete Action From All Principals, as to prevent leaking private information to the entire internet or allow unauthorized data tampering / deletion. This means the 'Effect' must not be 'Allow' when the 'Action' is Delete, for all Principals.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html">Documentation</a><br/>|
|S3 Bucket Allows List Action From All Principals<br/><sup><sub>d395a950-12ce-4314-a742-ac5a785ab44e</sub></sup>|<span style="color:#C00">High</span>|Access Control|S3 Buckets must not allow List Action From All Principals, as to prevent leaking private information to the entire internet or allow unauthorized data tampering / deletion. This means the 'Effect' must not be 'Allow' when the 'Action' is List, for all Principals.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html">Documentation</a><br/>|
|S3 Bucket Access to Any Principal<br/><sup><sub>3ab1f27d-52cc-4943-af1d-43c1939e739a</sub></sup>|<span style="color:#C00">High</span>|Access Control|Checks if the S3 bucket is accessible for all users|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html#ansible-collections-amazon-aws-s3-bucket-module">Documentation</a><br/>|
|Secure Ciphers Disabled<br/><sup><sub>218413a0-c716-4b94-9e08-0bb70d854709</sub></sup>|<span style="color:#C00">High</span>|Encryption|Check if secure ciphers aren't used in CloudFront|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html">Documentation</a><br/>|
|Redis Not Compliant<br/><sup><sub>9f34885e-c08f-4d13-a7d1-cf190c5bd268</sub></sup>|<span style="color:#C00">High</span>|Encryption|Check if the redis version is compliant with the necessary AWS PCI DSS requirements|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elasticache_module.html#parameter-cache_engine_version">Documentation</a><br/>|
|Launch Configuration Is Not Encrypted<br/><sup><sub>66477506-6abb-49ed-803d-3fa174cd5f6a</sub></sup>|<span style="color:#C00">High</span>|Encryption|AWS Autoscaling Launch Configurations should have the data in the volumes encrypted. To encrypt the data, the 'encrypted' parameter should be set to true in each volume|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ec2_lc_module.html">Documentation</a><br/>|
|CA Certificate Identifier Is Outdated<br/><sup><sub>5eccd62d-8b4d-46d3-83ea-1879f3cbd3ce</sub></sup>|<span style="color:#C00">High</span>|Encryption|The CA certificate Identifier must be 'rds-ca-2019'.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html#parameter-ca_certificate_identifier">Documentation</a><br/>|
|S3 Bucket Without Server-side-encryption<br/><sup><sub>594f54e7-f744-45ab-93e4-c6dbaf6cd571</sub></sup>|<span style="color:#C00">High</span>|Encryption|AWS S3 Storage should be protected with SSE (Server-Side Encryption)|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html">Documentation</a><br/>|
|EFS Without KMS<br/><sup><sub>bd77554e-f138-40c5-91b2-2a09f878608e</sub></sup>|<span style="color:#C00">High</span>|Encryption|Amazon Elastic Filesystem should have filesystem encryption enabled using KMS CMK customer-managed keys instead of AWS managed-keys|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/efs_module.html#parameter-kms_key_id">Documentation</a><br/>|
|IAM Database Auth Not Enabled<br/><sup><sub>0ed012a4-9199-43d2-b9e4-9bd049a48aa4</sub></sup>|<span style="color:#C00">High</span>|Encryption|IAM Database Auth Enabled must be configured to true|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html">Documentation</a><br/>|
|Kinesis Not Encrypted With KMS<br/><sup><sub>f2ea6481-1d31-4d40-946a-520dc6321dd7</sub></sup>|<span style="color:#C00">High</span>|Encryption|AWS Kinesis Streams and metadata should be protected with KMS|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/kinesis_stream_module.html">Documentation</a><br/>|
|User Data Contains Encoded Private Key<br/><sup><sub>c09f4d3e-27d2-4d46-9453-abbe9687a64e</sub></sup>|<span style="color:#C00">High</span>|Encryption|User Data contains an encoded RSA Private Key|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ec2_lc_module.html">Documentation</a><br/>|
|User Data Shell Script Is Encoded<br/><sup><sub>1e2341ba-a5cf-4f0a-a5f6-47e90c68ea89</sub></sup>|<span style="color:#C00">High</span>|Encryption|User Data Shell Script must be encoded|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ec2_lc_module.html">Documentation</a><br/>|
|EFS Not Encrypted<br/><sup><sub>727c4fd4-d604-4df6-a179-7713d3c85e20</sub></sup>|<span style="color:#C00">High</span>|Encryption|Elastic File System (EFS) must be encrypted|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/efs_module.html#parameter-encrypt">Documentation</a><br/>|
|ECS Task Definition Container With Plaintext Password<br/><sup><sub>7fdc2bf3-6bc0-4cb3-84c5-cfd041c0f892</sub></sup>|<span style="color:#C00">High</span>|Encryption|It's not recommended to use plaintext environment variables for sensitive information, such as credential data.|<a href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html#container_definition_environment">Documentation</a><br/>|
|DB Instance Storage Not Encrypted<br/><sup><sub>7dfb316c-a6c2-454d-b8a2-97f147b0c0ff</sub></sup>|<span style="color:#C00">High</span>|Encryption|The parameter storage_encrypted in aws_db_instance must be set to 'true' (the default is 'false').|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html">Documentation</a><br/>|
|S3 Bucket SSE Disabled<br/><sup><sub>309edc5b-5a59-42b4-a357-d4d098311fd4</sub></sup>|<span style="color:#C00">High</span>|Encryption|If algorithm is AES256 then the master key is null, empty or undefined, otherwise the master key is required|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html#parameter-encryption_key_id">Documentation</a><br/>|
|ELB Using Weak Ciphers<br/><sup><sub>2034fb37-bc23-4ca0-8d95-2b9f15829ab5</sub></sup>|<span style="color:#C00">High</span>|Encryption|ELB Predefined or Custom Security Policies must not use weak ciphers, to reduce the risk of the SSL connection between the client and the load balancer being exploited. That means the 'SslPolicy' of 'listeners' must not coincide with any of a predefined list of weak ciphers.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elb_application_lb_module.html">Documentation</a><br/>|
|Redshift Not Encrypted<br/><sup><sub>6a647814-def5-4b85-88f5-897c19f509cd</sub></sup>|<span style="color:#C00">High</span>|Encryption|AWS Redshift Cluster should be encrypted. Check if 'encrypted' field is false or undefined (default is false)|<a href="https://registry.terraform.io/providers/hashicorp/aws/latest/docs/resources/redshift_cluster#encrypted">Documentation</a><br/>|
|Viewer Protocol Policy Allows HTTP<br/><sup><sub>a6d27cf7-61dc-4bde-ae08-3b353b609f76</sub></sup>|<span style="color:#C00">High</span>|Encryption|Checks if the connection between the CloudFront and the origin server is encrypted|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html">Documentation</a><br/>|
|ELB Using Insecure Protocols<br/><sup><sub>730a5951-2760-407a-b032-dd629b55c23a</sub></sup>|<span style="color:#C00">High</span>|Encryption|ELB Predefined or Custom Security Policies must not use insecure protocols, to reduce the risk of the SSL connection between the client and the load balancer being exploited. That means the 'SslPolicy' of 'listeners' must not coincide with any of a predefined list of insecure protocols.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elb_application_lb_module.html">Documentation</a><br/>|
|AMI Not Encrypted<br/><sup><sub>97707503-a22c-4cd7-b7c0-f088fa7cf830</sub></sup>|<span style="color:#C00">High</span>|Encryption|AWS AMI Encryption is not enabled|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_ami_module.html">Documentation</a><br/>|
|CloudFront Without Minimum Protocol TLS 1.2<br/><sup><sub>d0c13053-d2c8-44a6-95da-d592996e9e67</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|CloudFront Minimum Protocol version should be at least TLS 1.2|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html#parameter-viewer_certificate/minimum_protocol_version">Documentation</a><br/>|
|ECS Task Definition Network Mode Not Recommended<br/><sup><sub>01aec7c2-3e4d-4274-ae47-2b8fea22fd1f</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Network_Mode should be 'awsvpc' in ecs_task_definition. AWS VPCs provides the controls to facilitate a formal process for approving and testing all network connections and changes to the firewall and router configurations|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ecs_taskdefinition_module.html#parameter-network_mode">Documentation</a><br/>|
|DB Instance Publicly Accessible<br/><sup><sub>c09e3ca5-f08a-4717-9c87-3919c5e6d209</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|RDS must not be defined with public interface, which means the field 'publicly_accessible' should not be set to 'true' (default is 'false').|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html#parameter-auto_minor_version_upgrade">Documentation</a><br/>|
|Root Account Has Active Access Keys<br/><sup><sub>e71d0bc7-d9e8-4e6e-ae90-0a4206db6f40</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|The AWS Root Account must not have active access keys associated, which means if there are access keys associated to the Root Account, they must be inactive.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_module.html">Documentation</a><br/>|
|S3 Bucket with Unsecured CORS Rule<br/><sup><sub>3505094c-f77c-4ba0-95da-f83db712f86c</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|If the CORS (Cross-Origin Resource Sharing) rule is defined in an S3 bucket, it should be secure|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_s3_cors_module.html#parameter-rules">Documentation</a><br/>|
|Redshift Publicly Accessible<br/><sup><sub>5c6b727b-1382-4629-8ba9-abd1365e5610</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|AWS Redshift Clusters must not be publicly accessible. Check if 'publicly_accessible' field is true (default is false)|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/redshift_module.html">Documentation</a><br/>|
|Batch Job Definition With Privileged Container Properties<br/><sup><sub>defe5b18-978d-4722-9325-4d1975d3699f</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Batch Job Definition should not have Privileged Container Properties|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_batch_job_definition_module.html">Documentation</a><br/>|
|EC2 Group Has Public Interface<br/><sup><sub>5330b503-3319-44ff-9b1c-00ee873f728a</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|The CIDR IP should not be a public interface|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|KMS Key With Vulnerable Policy<br/><sup><sub>5b9d237a-57d5-4177-be0e-71434b0fef47</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Checks if the policy is vulnerable and needs updating.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_kms_module.html">Documentation</a><br/>|
|Vulnerable Default SSL Certificate<br/><sup><sub>fb8f8929-afeb-4c46-99f0-a6cf410f7df4</sub></sup>|<span style="color:#C00">High</span>|Insecure Defaults|CloudFront web distributions should use custom (and not default) SSL certificates. Custom SSL certificates allow only defined users to access content by using an alternate domain name instead of the default one.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html">Documentation</a><br/>|
|Unknown Port Exposed To Internet<br/><sup><sub>722b0f24-5a64-4cca-aa96-cfc26b7e3a5b</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|AWS Security Group should not have an unknown port exposed to the entire Internet|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|EC2 Instance Has Public IP<br/><sup><sub>a8b0c58b-cd25-4b53-9ad0-55bca0be0bc1</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|EC2 Instance should not have a public IP address.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_module.html#parameter-assign_public_ip">Documentation</a><br/>|
|Public Port Wide<br/><sup><sub>71ea648a-d31a-4b5a-a589-5674243f1c33</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|AWS Security Group should not have public port wide|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|RDS Associated with Public Subnet<br/><sup><sub>16732649-4ff6-4cd2-8746-e72c13fae4b8</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|RDS should not run in public subnet|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html#parameter-db_subnet_group_name">Documentation</a><br/>|
|DB Security Group Open To Large Scope<br/><sup><sub>ea0ed1c7-9aef-4464-b7c7-94c762da3640</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|The IP address in a DB Security Group must not have more than 256 hosts.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html#ansible-collections-amazon-aws-ec2-group-module">Documentation</a><br/>|
|HTTP Port Open To Internet<br/><sup><sub>a14ad534-acbe-4a8e-9404-2f7e1045646e</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|The HTTP port is open to the internet in a Security Group|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html#ansible-collections-amazon-aws-ec2-group-module">Documentation</a><br/>|
|Security Group Ingress Not Restricted<br/><sup><sub>ea6bc7a6-d696-4dcf-a788-17fa03c17c81</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|AWS Security Group should restrict ingress access|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|Unrestricted Security Group Ingress<br/><sup><sub>83c5fa4c-e098-48fc-84ee-0a537287ddd2</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Security groups allow ingress from 0.0.0.0/0|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|ALB Listening on HTTP<br/><sup><sub>f81d63d2-c5d7-43a4-a5b5-66717a41c895</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|AWS Application Load Balancer (alb) should not listen on HTTP|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elb_application_lb_module.html">Documentation</a><br/>|
|Default Security Groups With Unrestricted Traffic<br/><sup><sub>8010e17a-00e9-4635-a692-90d6bcec68bd</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Check if default security group does not restrict all inbound and outbound traffic.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|DB Security Group With Public Scope<br/><sup><sub>0956aedf-6a7a-478b-ab56-63e2b19923ad</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|The IP address in a DB Security Group must not be '0.0.0.0/0' (IPv4) or '::/0' (IPv6).|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|Route53 Record Undefined<br/><sup><sub>445dce51-7e53-4e50-80ef-7f94f14169e4</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Route53 Record should have a list of records|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/route53_module.html#parameter-value">Documentation</a><br/>|
|Security Group With Unrestricted Access To SSH<br/><sup><sub>57ced4b9-6ba4-487b-8843-b65562b90c77</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|'SSH' (TCP:22) should not be public in AWS Security Group|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|Remote Desktop Port Open To Internet<br/><sup><sub>eda7301d-1f3e-47cf-8d4e-976debc64341</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|The Remote Desktop port is open to the internet in a Security Group|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html#ansible-collections-amazon-aws-ec2-group-module">Documentation</a><br/>|
|CloudTrail Logging Disabled<br/><sup><sub>d4a73c49-cbaa-4c6f-80ee-d6ef5a3a26f5</sub></sup>|<span style="color:#C00">High</span>|Observability|Checks if logging is enabled for CloudTrail.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudtrail_module.html#parameter-enable_logging">Documentation</a><br/>|
|CMK Rotation Disabled<br/><sup><sub>af96d737-0818-4162-8c41-40d969bd65d1</sub></sup>|<span style="color:#C00">High</span>|Observability|Customer Master Keys (CMK) must have rotation enabled, which means the attribute 'enable_key_rotation' must be set to 'true' when the key is enabled.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_kms_module.html#parameter-enable_key_rotation">Documentation</a><br/>|
|Configuration Aggregator to All Regions Disabled<br/><sup><sub>a2fdf451-89dd-451e-af92-bf6c0f4bab96</sub></sup>|<span style="color:#C00">High</span>|Observability|AWS Config Configuration Aggregator All Regions must be set to True|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_config_aggregator_module.html#parameter-organization_source">Documentation</a><br/>|
|API Gateway Without Configured Authorizer<br/><sup><sub>b16cdb37-ce15-4ab2-8401-d42b05d123fc</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|API Gateway REST API should have an API Gateway Authorizer|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_api_gateway_module.html">Documentation</a><br/>|
|Public Lambda via API Gateway<br/><sup><sub>5e92d816-2177-4083-85b4-f61b4f7176d9</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Allowing to run lambda function using public API Gateway|<a href="https://docs.ansible.com/ansible/2.4/lambda_policy_module.html">Documentation</a><br/>|
|IAM Access Key Is Exposed<br/><sup><sub>7f79f858-fbe8-4186-8a2c-dfd0d958a40f</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Check if IAM Access Key is active for some user besides 'root'|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_module.html">Documentation</a><br/>|
|SQS Policy With Public Access<br/><sup><sub>d994585f-defb-4b51-b6d2-c70f020ceb10</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Checks for dangerous permissions in Action statements in an SQS Queue Policy. This is deemed a potential security risk as it would allow various attacks to the queue|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/sqs_queue_module.html">Documentation</a><br/>|
|ECR Repository Is Publicly Accessible<br/><sup><sub>fb5a5df7-6d74-4243-ab82-ff779a958bfd</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Amazon ECR image repositories shouldn't have public access|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ecs_ecr_module.html#parameter-policy">Documentation</a><br/>|
|Cross-Account IAM Assume Role Policy Without ExternalId or MFA<br/><sup><sub>af167837-9636-4086-b815-c239186b9dda</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Cross-Account IAM Assume Role Policy should require external ID or MFA to protect cross-account access|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_role_module.html#parameter-assume_role_policy_document">Documentation</a><br/>|
|AMI Shared With Multiple Accounts<br/><sup><sub>a19b2942-142e-4e2b-93b7-6cf6a6c8d90f</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Limits access to AWS AMIs by checking if more than one account is using the same image|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_ami_module.html">Documentation</a><br/>|
|Certificate Has Expired<br/><sup><sub>5a443297-19d4-4381-9e5b-24faf947ec22</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Expired SSL/TLS certificates should be removed|<a href="https://docs.ansible.com/ansible/2.10/collections/community/aws/aws_acm_module.html">Documentation</a><br/>|
|S3 Bucket With Public Access<br/><sup><sub>c3e073c1-f65e-4d18-bd67-4a8f20ad1ab9</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|S3 Bucket allows public access|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/aws_s3_module.html#parameter-permission">Documentation</a><br/>|
|SES Policy With Allowed IAM Actions<br/><sup><sub>8ed0bfce-f780-46d4-b086-21c3628f09ad</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|SES policy should not allow IAM actions to all principals|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_ses_identity_policy_module.html#parameter-policy">Documentation</a><br/>|
|Lambda Permission Principal Is Wildcard<br/><sup><sub>1d972c56-8ec2-48c1-a578-887adb09c57a</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Lambda Permission Principal should not contain a wildcard.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/lambda_policy_module.html">Documentation</a><br/>|
|SQS Policy Allows All Actions<br/><sup><sub>ed9b3beb-92cf-44d9-a9d2-171eeba569d4</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|SQS policy allows ALL (*) actions|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/sqs_queue_module.html">Documentation</a><br/>|
|Auto Scaling Group With No Associated ELB<br/><sup><sub>050f085f-a8db-4072-9010-2cca235cc02f</sub></sup>|<span style="color:#C60">Medium</span>|Availability|AWS Auto Scaling Groups must have associated ELBs to ensure high availability and improve application performance. This means the attribute 'load_balancers' must be defined and not empty.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ec2_asg_module.html#parameter-load_balancers">Documentation</a><br/>|
|CMK Is Unusable<br/><sup><sub>133fee21-37ef-45df-a563-4d07edc169f4</sub></sup>|<span style="color:#C60">Medium</span>|Availability|AWS Key Management Service (KMS) must only possess usable Customer Master Keys (CMK), which means the CMKs must have the attribute 'enabled' set to true and the attribute 'pending_window' must be undefined.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_kms_module.html#parameter-enabled">Documentation</a><br/>|
|ECS Service Without Running Tasks<br/><sup><sub>f5c45127-1d28-4b49-a692-0b97da1c3a84</sub></sup>|<span style="color:#C60">Medium</span>|Availability|ECS Service should have at least 1 task running|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ecs_service_module.html#ansible-collections-community-aws-ecs-service-module">Documentation</a><br/>|
|RDS With Backup Disabled<br/><sup><sub>e69890e6-fce5-461d-98ad-cb98318dfc96</sub></sup>|<span style="color:#C60">Medium</span>|Backup|Make sure the AWS RDS configuration has automatic backup configured. If the retention period is equal to 0 there is no backup|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html#parameter-backup_retention_period">Documentation</a><br/>|
|Stack Retention Disabled<br/><sup><sub>17d5ba1d-7667-4729-b1a6-b11fde3db7f7</sub></sup>|<span style="color:#C60">Medium</span>|Backup|Make sure that retain_stack is enabled to keep the Stack and it's associated resources during resource destruction|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudformation_stack_set_module.html#parameter-purge_stacks">Documentation</a><br/>|
|IAM Password Without Minimum Length<br/><sup><sub>8bc2168c-1723-4eeb-a6f3-a1ba614b9a6d</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|IAM password should have the required minimum length|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html">Documentation</a><br/>|
|Password Without Reuse Prevention<br/><sup><sub>6f5f5444-1422-495f-81ef-24cefd61ed2c</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|Password policy `password_reuse_prevention` doesn't exist or is equal to 0|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html#parameter-pw_reuse_prevent">Documentation</a><br/>|
|Authentication Without MFA<br/><sup><sub>eee107f9-b3d8-45d3-b9c6-43b5a7263ce1</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|Users should authenticate with MFA (Multi-factor Authentication)|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_mfa_device_info_module.html">Documentation</a><br/>|
|Misconfigured Password Policy Expiration<br/><sup><sub>3f2cf811-88fa-4eda-be45-7a191a18aba9</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|No password expiration policy|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html">Documentation</a><br/>|
|IAM Password Without Lowercase Letter<br/><sup><sub>8e3063f4-b511-45c3-b030-f3b0c9131951</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|IAM Password should have at least one lowercase letter|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html">Documentation</a><br/>|
|IAM Password Without Number<br/><sup><sub>9cf25d62-0b96-42c8-b66d-998cd6ee5bb8</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|Check if IAM account password has at least one number|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html">Documentation</a><br/>|
|IAM Password Without Uppercase Letter<br/><sup><sub>83957b81-39c1-4191-8e12-671d2ce14354</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|IAM password should have at least one uppercase letter|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html">Documentation</a><br/>|
|Stack Without Template<br/><sup><sub>32d31f1f-0f83-4721-b7ec-1e6948c60145</sub></sup>|<span style="color:#C60">Medium</span>|Build Process|AWS CloudFormation should have a template defined through the attribute template, template_url or attribute template_body|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/cloudformation_module.html">Documentation</a><br/>|
|EBS Volume Encryption Disabled<br/><sup><sub>4b6012e7-7176-46e4-8108-e441785eae57</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|EBS volumes should be encrypted|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_vol_module.html#parameter-encrypted">Documentation</a><br/>|
|SQS with SSE disabled<br/><sup><sub>e1e7b278-2a8b-49bd-a26e-66a7f70b17eb</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|Amazon Simple Queue Service (SQS) queue is not protecting the contents of their messages using Server-Side Encryption (SSE)|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/sqs_queue_module.html#ansible-collections-community-aws-sqs-queue-module">Documentation</a><br/>|
|CodeBuild Not Encrypted<br/><sup><sub>a1423864-2fbc-4f46-bfe1-fbbf125c71c9</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|CodeBuild Project should be encrypted|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_codebuild_module.html">Documentation</a><br/>|
|Config Rule For Encrypted Volumes Disabled<br/><sup><sub>7674a686-e4b1-4a95-83d4-1fd53c623d84</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|Check if AWS config rules do not identify Encrypted Volumes as a source.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_config_rule_module.html#parameter-source/identifier">Documentation</a><br/>|
|Memcached Disabled<br/><sup><sub>2d55ef88-b616-4890-b822-47f280763e89</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|Check if the Memcached is disabled on the ElastiCache|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elasticache_module.html#parameter-engine">Documentation</a><br/>|
|Instance With No VPC<br/><sup><sub>61d1a2d0-4db8-405a-913d-5d2ce49dff6f</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|EC2 Instances should be configured under a VPC network. AWS VPCs provide the controls to facilitate a formal process for approving and testing all network connections and changes to the firewall and router configurations.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_module.html">Documentation</a><br/>|
|ECR Image Tag Not Immutable<br/><sup><sub>60bfbb8a-c72f-467f-a6dd-a46b7d612789</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|ECR should have an image tag be immutable. This prevents image tags from being overwritten.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ecs_ecr_module.html">Documentation</a><br/>|
|Certificate RSA Key Bytes Lower Than 256<br/><sup><sub>d5ec2080-340a-4259-b885-f833c4ea6a31</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|The certificate should use a RSA key with a length equal to or higher than 256 bytes|<a href="https://docs.ansible.com/ansible/2.10/collections/community/aws/aws_acm_module.html">Documentation</a><br/>|
|Lambda Function Without Tags<br/><sup><sub>265d9725-2fb8-42a2-bc57-3279c5db82d5</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|AWS Lambda Functions must have associated tags.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/lambda_module.html">Documentation</a><br/>|
|API Gateway Without SSL Certificate<br/><sup><sub>b47b98ab-e481-4a82-8bb1-1ab39fd36e33</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|SSL Client Certificate should be enabled|<a href="https://docs.ansible.com/ansible/2.8/modules/aws_api_gateway_module.html">Documentation</a><br/>|
|AWS Password Policy With Unchangeable Passwords<br/><sup><sub>e28ceb92-d588-4166-aac5-766c8f5b7472</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Unchangeable passwords in AWS password policy|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_password_policy_module.html">Documentation</a><br/>|
|SQL Analysis Services Port 2383 (TCP) is Publicly Accessible<br/><sup><sub>7af1c447-c014-4f05-bd8b-ebe3a15734ac</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Check if port 2383 on TCP is publicly accessible by checking the CIDR block range that can access it.|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_group_module.html">Documentation</a><br/>|
|API Gateway without WAF<br/><sup><sub>f5f38943-664b-4acc-ab11-f292fa10ed0b</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|API Gateway should have WAF (Web Application Firewall) enabled|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/wafv2_resources_module.html#parameter-arn">Documentation</a><br/>|
|API Gateway Endpoint Config is Not Private<br/><sup><sub>559439b2-3e9c-4739-ac46-17e3b24ec215</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|The API Endpoint type in API Gateway should be set to PRIVATE so it's not exposed to the public internet|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_api_gateway_module.html">Documentation</a><br/>|
|Cloudfront Logging Disabled<br/><sup><sub>d31cb911-bf5b-4eb6-9fc3-16780c77c7bd</sub></sup>|<span style="color:#C60">Medium</span>|Observability|AWS Cloudfront distributions must have logging enabled, which means the attribute 'logging' must be defined with 'enabled' set to true|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html">Documentation</a><br/>|
|CloudTrail Not Integrated With CloudWatch<br/><sup><sub>ebb2118a-03bc-4d53-ab43-d8750f5cb8d3</sub></sup>|<span style="color:#C60">Medium</span>|Observability|CloudTrail should be integrated with CloudWatch|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudtrail_module.html">Documentation</a><br/>|
|API Gateway With CloudWatch Logging Disabled<br/><sup><sub>72a931c2-12f5-40d1-93cc-47bff2f7aa2a</sub></sup>|<span style="color:#C60">Medium</span>|Observability|AWS CloudWatch Logs for APIs is not enabled|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudwatchlogs_log_group_module.html#ansible-collections-community-aws-cloudwatchlogs-log-group-module">Documentation</a><br/>|
|CloudTrail Multi Region Disabled<br/><sup><sub>6ad087d7-a509-4b20-b853-9ef6f5ebaa98</sub></sup>|<span style="color:#C60">Medium</span>|Observability|CloudTrail multi region should be enabled, which means attribute 'is_multi_region_trail' should be set to true|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudtrail_module.html#parameter-is_multi_region_trail">Documentation</a><br/>|
|S3 Bucket Without Versioning<br/><sup><sub>9232306a-f839-40aa-b3ef-b352001da9a5</sub></sup>|<span style="color:#C60">Medium</span>|Observability|S3 bucket should have versioning enabled|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html#parameter-versioning">Documentation</a><br/>|
|CloudTrail SNS Topic Name Undefined<br/><sup><sub>5ba316a9-c466-4ec1-8d5b-bc6107dc9a92</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Check if SNS topic name is set for CloudTrail|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudtrail_module.html">Documentation</a><br/>|
|Stack Notifications Disabled<br/><sup><sub>d39761d7-94ab-45b0-ab5e-27c44e381d58</sub></sup>|<span style="color:#C60">Medium</span>|Observability|AWS CloudFormation should have stack notifications enabled|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/cloudformation_module.html#parameter-notification_arns">Documentation</a><br/>|
|CloudWatch Without Retention Period Specified<br/><sup><sub>e24e18d9-4c2b-4649-b3d0-18c088145e24</sub></sup>|<span style="color:#C60">Medium</span>|Observability|AWS CloudWatch should have CloudWatch Logs enabled in order to monitor, store, and access log events|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudwatchlogs_log_group_module.html">Documentation</a><br/>|
|API Gateway X-Ray Disabled<br/><sup><sub>2059155b-27fd-441e-b616-6966c468561f</sub></sup>|<span style="color:#C60">Medium</span>|Observability|API Gateway should have X-Ray Tracing enabled|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/aws_api_gateway_module.html#parameter-tracing_enabled">Documentation</a><br/>|
|No Stack Policy<br/><sup><sub>ffe0fd52-7a8b-4a5c-8fc7-49844418e6c9</sub></sup>|<span style="color:#C60">Medium</span>|Resource Management|AWS CloudFormation Stack should have a stack policy in order to protect stack resources from update actions|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/cloudformation_module.html">Documentation</a><br/>|
|Hardcoded AWS Access Key In Lambda<br/><sup><sub>f34508b9-f574-4330-b42d-88c44cced645</sub></sup>|<span style="color:#C60">Medium</span>|Secret Management|Lambda access key should not be in plaintext.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/lambda_module.html">Documentation</a><br/>|
|IAM Policy Grants 'AssumeRole' Permission Across All Services<br/><sup><sub>12a7a7ce-39d6-49dd-923d-aeb4564eb66c</sub></sup>|<span style="color:#CC0">Low</span>|Access Control|IAM Policy should not grant 'AssumeRole' permission across all services.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_managed_policy_module.html">Documentation</a><br/>|
|IAM Role Allows All Principals To Assume<br/><sup><sub>babdedcf-d859-43da-9a7b-6d72e661a8fd</sub></sup>|<span style="color:#CC0">Low</span>|Access Control|IAM role allows all services or principals to assume it|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_managed_policy_module.html">Documentation</a><br/>|
|EC2 Instance Using Default Security Group<br/><sup><sub>8d03993b-8384-419b-a681-d1f55149397c</sub></sup>|<span style="color:#CC0">Low</span>|Access Control|EC2 instances should not use default security group(s)|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_module.html#parameter-group">Documentation</a><br/>|
|IAM Group Without Users<br/><sup><sub>f509931b-bbb0-443c-bd9b-10e92ecf2193</sub></sup>|<span style="color:#CC0">Low</span>|Access Control|IAM Group should have at least one user associated|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_group_module.html">Documentation</a><br/>|
|IAM Policies Attached To User<br/><sup><sub>eafe4bc3-1042-4f88-b988-1939e64bf060</sub></sup>|<span style="color:#CC0">Low</span>|Best Practices|IAM policies should be attached only to groups or roles|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/iam_policy_module.html">Documentation</a><br/>|
|Automatic Minor Upgrades Disabled<br/><sup><sub>857f8808-e96a-4ba8-a9b7-f2d4ec6cad94</sub></sup>|<span style="color:#CC0">Low</span>|Best Practices|RDS instance should have automatic minor upgrades enabled, which means the attribute 'auto_minor_version_upgrade' must be set to true.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html#parameter-auto_minor_version_upgrade">Documentation</a><br/>|
|CDN Configuration Is Missing<br/><sup><sub>b25398a2-0625-4e61-8e4d-a1bb23905bf6</sub></sup>|<span style="color:#CC0">Low</span>|Best Practices|Content Delivery Network (CDN) service is used within an AWS account to secure and accelerate the delivery of websites. The use of a CDN can provide a layer of security between your origin content and the destination.|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html">Documentation</a><br/>|
|Lambda Permission Misconfigured<br/><sup><sub>3ddf3417-424d-420d-8275-0724dc426520</sub></sup>|<span style="color:#CC0">Low</span>|Best Practices|Lambda permission may be misconfigured if the action field is not filled in by 'lambda:InvokeFunction'|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/lambda_policy_module.html">Documentation</a><br/>|
|EFS Without Tags<br/><sup><sub>b8a9852c-9943-4973-b8d5-77dae9352851</sub></sup>|<span style="color:#CC0">Low</span>|Build Process|Amazon Elastic Filesystem should have filesystem tags associated|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/efs_module.html">Documentation</a><br/>|
|CloudTrail Log Files Not Encrypted With CMK<br/><sup><sub>f5587077-3f57-4370-9b4e-4eb5b1bac85b</sub></sup>|<span style="color:#CC0">Low</span>|Encryption|CloudTrail Log Files should be encrypted with Key Management Service (KMS)|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudtrail_module.html">Documentation</a><br/>|
|Redshift Using Default Port<br/><sup><sub>e01de151-a7bd-4db4-b49b-3c4775a5e881</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|Redshift should not use the default port (5439) because an attacker can easily guess the port|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/redshift_module.html#parameter-port">Documentation</a><br/>|
|ElastiCache Without VPC<br/><sup><sub>5527dcfc-94f9-4bf6-b7d4-1b78850cf41f</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|ElastiCache should be launched in a Virtual Private Cloud (VPC)|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elasticache_module.html#parameter-cache_subnet_group">Documentation</a><br/>|
|EC2 Instance Using Default VPC<br/><sup><sub>8833f180-96f1-46f4-9147-849aafa56029</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|EC2 Instances should not be configured under a default VPC network|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_module.html#parameter-vpc_subnet_id">Documentation</a><br/>|
|Cloudfront Without WAF<br/><sup><sub>22c80725-e390-4055-8d14-a872230f6607</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|All AWS CloudFront distributions should be integrated with the Web Application Firewall (AWS WAF) service|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudfront_distribution_module.html">Documentation</a><br/>|
|ElastiCache Using Default Port<br/><sup><sub>7cc6c791-5f68-4816-a564-b9b699f9d26e</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|ElastiCache should not use the default port (an attacker can easily guess the port). For engine set to Redis, the default port is 6379. The Memcached default port is 11211|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/elasticache_module.html#parameter-cache_port">Documentation</a><br/>|
|RDS Using Default Port<br/><sup><sub>2cb674f6-32f9-40be-97f2-62c0dc38f0d5</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|RDS should not use the default port (an attacker can easily guess the port). For engines related to Aurora, MariaDB or MySQL, the default port is 3306. PostgreSQL default port is 5432, Oracle default port is 1521 and SQL Server default port is 1433|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/rds_instance_module.html#parameter-port">Documentation</a><br/>|
|S3 Bucket Logging Disabled<br/><sup><sub>c3b9f7b0-f5a0-49ec-9cbc-f1e346b7274d</sub></sup>|<span style="color:#CC0">Low</span>|Observability|S3 bucket without debug_botocore_endpoint_logs|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/s3_bucket_module.html#parameter-debug_botocore_endpoint_logs">Documentation</a><br/>|
|CloudTrail Log File Validation Disabled<br/><sup><sub>4d8681a2-3d30-4c89-8070-08acd142748e</sub></sup>|<span style="color:#CC0">Low</span>|Observability|CloudTrail Log Files should have validation enabled|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/cloudtrail_module.html">Documentation</a><br/>|
|Lambda Functions Without X-Ray Tracing<br/><sup><sub>71397b34-1d50-4ee1-97cb-c96c34676f74</sub></sup>|<span style="color:#CC0">Low</span>|Observability|AWS Lambda functions should have TracingConfig enabled. For this, property 'tracing_mode' should have the value 'Active'|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/lambda_module.html">Documentation</a><br/>|
|Hardcoded AWS Access Key<br/><sup><sub>c2f15af3-66a0-4176-a56e-e4711e502e5c</sub></sup>|<span style="color:#CC0">Low</span>|Secret Management|Check if the user data in the EC2 instance has the access key hardcoded|<a href="https://docs.ansible.com/ansible/latest/collections/community/aws/ec2_instance_module.html">Documentation</a><br/>|
|EC2 Not EBS Optimized<br/><sup><sub>338b6cab-961d-4998-bb49-e5b6a11c9a5c</sub></sup>|<span style="color:#00C">Info</span>|Best Practices|It's considered a best practice for an EC2 instance to use an EBS optimized instance. This provides the best performance for your EBS volumes by minimizing contention between Amazon EBS I/O and other traffic from your instance|<a href="https://docs.ansible.com/ansible/latest/collections/amazon/aws/ec2_module.html#parameter-ebs_optimized">Documentation</a><br/>|
### AZURE
Bellow are listed queries related with Ansible AZURE:



|            Query             |Severity|Category|Description|Help|
|------------------------------|--------|--------|-----------|----|
|Admin User Enabled For Container Registry<br/><sup><sub>29f35127-98e6-43af-8ec1-201b79f99604</sub></sup>|<span style="color:#C00">High</span>|Access Control|Admin user is enabled for Container Registry|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_containerregistry_module.html">Documentation</a><br/>|
|Storage Container Is Publicly Accessible<br/><sup><sub>4d3817db-dd35-4de4-a80d-3867157e7f7f</sub></sup>|<span style="color:#C00">High</span>|Access Control|Anonymous, public read access to a container and its blobs are enabled in Azure Blob Storage|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_storageblob_module.html#parameter-public_access">Documentation</a><br/>|
|Public Storage Account<br/><sup><sub>35e2f133-a395-40de-a79d-b260d973d1bd</sub></sup>|<span style="color:#C00">High</span>|Access Control|Check if 'network_acls' is open to public.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_storageaccount_module.html#parameter-network_acls">Documentation</a><br/>|
|Storage Account Not Forcing HTTPS<br/><sup><sub>2c99a474-2a3c-4c17-8294-53ffa5ed0522</sub></sup>|<span style="color:#C00">High</span>|Encryption|See that Storage Accounts forces the use of HTTPS|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_storageaccount_module.html#parameter-https_only">Documentation</a><br/>|
|SSL Enforce Disabled<br/><sup><sub>961ce567-a16d-4d7d-9027-f0ec2628a555</sub></sup>|<span style="color:#C00">High</span>|Encryption|Make sure that for PosgreSQL, the 'Enforce SSL connection' is set to 'ENABLED'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlserver_module.html#parameter-enforce_ssl">Documentation</a><br/>|
|MySQL SSL Connection Disabled<br/><sup><sub>2a901825-0f3b-4655-a0fe-e0470e50f8e6</sub></sup>|<span style="color:#C00">High</span>|Encryption|Make sure that for MySQL Database Server, 'Enforce SSL connection' is enabled|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_mysqlserver_module.html">Documentation</a><br/>|
|Web App Accepting Traffic Other Than HTTPS<br/><sup><sub>eb8c2560-8bee-4248-9d0d-e80c8641dd91</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Web app should only accept HTTPS traffic in Azure Web App Service.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_webapp_module.html#parameter-https_only">Documentation</a><br/>|
|Azure Container Registry With No Locks<br/><sup><sub>581dae78-307d-45d5-aae4-fe2b0db267a5</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Azurerm Container Registry should contain associated locks through 'azure_rm_lock.managed_resource_id' or 'azure_rm_lock.resource_group' association|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_lock_module.html">Documentation</a><br/>|
|VM Not Attached To Network<br/><sup><sub>1e5f5307-3e01-438d-8da6-985307ed25ce</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|No Network Security Group is attached to the Virtual Machine|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_virtualmachine_module.html#parameter-network_interface_names">Documentation</a><br/>|
|AD Admin Not Configured For SQL Server<br/><sup><sub>b176e927-bbe2-44a6-a9c3-041417137e5f</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|The Active Directory Administrator is not configured for a SQL server|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_sqlserver_module.html#parameter-ad_user">Documentation</a><br/>|
|Redis Publicly Accessible<br/><sup><sub>0632d0db-9190-450a-8bb3-c283bffea445</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Firewall rule allowing unrestricted access to Redis from other Azure sources|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_rediscachefirewallrule_module.html#parameter-start_ip_address">Documentation</a><br/>|
|SQLServer Ingress From Any IP<br/><sup><sub>f4e9ff70-0f3b-4c50-a713-26cbe7ec4039</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Check if all IPs are allowed, check from start 0.0.0.0 to end 255.255.255.255.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_sqlfirewallrule_module.html">Documentation</a><br/>|
|Trusted Microsoft Services Not Enabled<br/><sup><sub>1bc398a8-d274-47de-a4c8-6ac867b353de</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Trusted Microsoft Services should be enabled for Storage Account access|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_storageaccount_module.html#parameter-network_acls/bypass">Documentation</a><br/>|
|CosmosDB Account IP Range Filter Not Set<br/><sup><sub>e8c80448-31d8-4755-85fc-6dbab69c2717</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|The IP range filter should be defined|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_cosmosdbaccount_module.html#parameter-ip_range_filter">Documentation</a><br/>|
|Redis Entirely Accessible<br/><sup><sub>0d0c12b9-edce-4510-9065-13f6a758750c</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Firewall rule allowing unrestricted access to Redis from the Internet|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_rediscachefirewallrule_module.html#parameter-start_ip_address">Documentation</a><br/>|
|Sensitive Port Is Exposed To Entire Network<br/><sup><sub>0ac9abbc-6d7a-41cf-af23-2e57ddb3dbfc</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|A sensitive port, such as port 23 or port 110, is open for the whole network in either TCP or UDP protocol|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_securitygroup_module.html#parameter-rules">Documentation</a><br/>|
|AKS RBAC Disabled<br/><sup><sub>149fa56c-4404-4f90-9e25-d34b676d5b39</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Azure Container Service (AKS) instance should have role-based access control (RBAC) enabled|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_aks_module.html">Documentation</a><br/>|
|Role Definition Allows Custom Role Creation<br/><sup><sub>5c80db8e-03f5-43a2-b4af-1f3f87018157</sub></sup>|<span style="color:#C60">Medium</span>|Access Control|Role Definition should not allow custom role creation (Microsoft.Authorization/roleDefinitions/write)|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_roledefinition_module.html#parameter-permissions/actions">Documentation</a><br/>|
|Key Vault Soft Delete Is Disabled<br/><sup><sub>881696a8-68c5-4073-85bc-7c38a3deb854</sub></sup>|<span style="color:#C60">Medium</span>|Backup|Make sure Soft Delete is enabled for Key Vault|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_keyvault_module.html#parameter-enable_soft_delete">Documentation</a><br/>|
|SQL Server Predictable Admin Account Name<br/><sup><sub>663062e9-473d-4e87-99bc-6f3684b3df40</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|Azure SQL Server's Admin account login must avoid using names like 'Admin', that are too predictable, which means the attribute 'admin_username' must be set to a name that is not easy to predict|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_sqlserver_module.html">Documentation</a><br/>|
|Unrestricted SQL Server Access<br/><sup><sub>3f23c96c-f9f5-488d-9b17-605b8da5842f</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|Azure SQL Server Accessibility should be set to a minimal address range, which means the difference between the values of the 'end_ip_address' and 'start_ip_address' must be lesser than 256. Additionally, both ips must be different from '0.0.0.0'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_sqlfirewallrule_module.html">Documentation</a><br/>|
|SQL Server Predictable Active Directory Account Name<br/><sup><sub>530e8291-2f22-4bab-b7ea-306f1bc2a308</sub></sup>|<span style="color:#C60">Medium</span>|Best Practices|Azure SQL Server must avoid using predictable Active Directory Administrator Account names, like 'Admin', which means the attribute 'ad_user' must be set to a name that is not easy to predict|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_adserviceprincipal_module.html">Documentation</a><br/>|
|Cosmos DB Account Without Tags<br/><sup><sub>23a4dc83-4959-4d99-8056-8e051a82bc1e</sub></sup>|<span style="color:#C60">Medium</span>|Build Process|Cosmos DB Account must have a mapping of tags.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_cosmosdbaccount_module.html">Documentation</a><br/>|
|Storage Account Not Using Latest TLS Encryption Version<br/><sup><sub>c62746cf-92d5-4649-9acf-7d48d086f2ee</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|Ensure Storage Account is using the latest version of TLS encryption|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_storageaccount_module.html#parameter-minimum_tls_version">Documentation</a><br/>|
|Redis Cache Allows Non SSL Connections<br/><sup><sub>869e7fb4-30f0-4bdb-b360-ad548f337f2f</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Check if any Redis Cache resource allows non-SSL connections.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_rediscache_module.html">Documentation</a><br/>|
|AKS Network Policy Misconfigured<br/><sup><sub>8c3bedf1-c570-4c3b-b414-d068cd39a00c</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Azure Kubernetes Service should have the proper network policy configuration|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_aks_module.html#parameter-network_profile/network_policy">Documentation</a><br/>|
|Security Group is Not Configured<br/><sup><sub>da4f2739-174f-4cdd-b9ef-dc3f14b5931f</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Azure Virtual Network subnet must be configured with a Network Security Group, which means the attribute 'security_group' must be defined and not empty|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_subnet_module.html">Documentation</a><br/>|
|Default Network Access is Allowed<br/><sup><sub>974e6fe7-63fd-4fa4-aa72-77b21a4a959d</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Defaults|Default Network Access rule for Storage Accounts must be set to deny, which means the attribute 'default_action' must be 'Deny'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_storageaccount_module.html">Documentation</a><br/>|
|WAF Is Disabled For Azure Application Gateway<br/><sup><sub>2fc5ab5a-c5eb-4ae4-b687-0f16fe77c255</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Check if Web Application Firewall is disabled or not configured for Azure's Application Gateway.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_appgateway_module.html">Documentation</a><br/>|
|Firewall Rule Allows Too Many Hosts To Access Redis Cache<br/><sup><sub>69f72007-502e-457b-bd2d-5012e31ac049</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Check if any firewall rule allows too many hosts to access Redis Cache.|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_rediscachefirewallrule_module.html">Documentation</a><br/>|
|PostgreSQL Log Duration Not Set<br/><sup><sub>729ebb15-8060-40f7-9017-cb72676a5487</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Make sure that for PostgreSQL Database, server parameter 'log_duration' is set to 'ON'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlconfiguration_module.html">Documentation</a><br/>|
|PostgreSQL Server Without Connection Throttling<br/><sup><sub>a9becca7-892a-4af7-b9e1-44bf20a4cd9a</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Ensure that Connection Throttling is set for the PostgreSQL server|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlconfiguration_module.html">Documentation</a><br/>|
|PostgreSQL Log Checkpoints Disabled<br/><sup><sub>7ab33ac0-e4a3-418f-a673-50da4e34df21</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Make sure that for Postgre SQL Database Server, parameter 'log_checkpoints' is set to 'ON'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlconfiguration_module.html">Documentation</a><br/>|
|AKS Monitoring Logging Disabled<br/><sup><sub>d5e83b32-56dd-4247-8c2e-074f43b38a5e</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Azure Container Service (AKS) instance should have logging enabled to Azure Monitoring|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_aks_module.html">Documentation</a><br/>|
|PostgreSQL Log Connections Not Set<br/><sup><sub>7b47138f-ec0e-47dc-8516-e7728fe3cc17</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Make sure that for PostgreSQL Database, server parameter 'log_connections' is set to 'ON'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlconfiguration_module.html">Documentation</a><br/>|
|PostgreSQL Log Disconnections Not Set<br/><sup><sub>054d07b5-941b-4c28-8eef-18989dc62323</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Make sure that for PostgreSQL Database, server parameter 'log_disconnections' is set to 'ON'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlconfiguration_module.html">Documentation</a><br/>|
|Small Activity Log Retention Period<br/><sup><sub>37fafbea-dedb-4e0d-852e-d16ee0589326</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Ensure that Activity Log Retention is set 365 days or greater|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_monitorlogprofile_module.html">Documentation</a><br/>|
|Log Retention Is Not Set<br/><sup><sub>0461b4fd-21ef-4687-929e-484ee4796785</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Make sure that for PostgreSQL Database, server parameter 'log_retention' is set to 'ON'|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_postgresqlconfiguration_module.html">Documentation</a><br/>|
|Monitoring Log Profile Without All Activities<br/><sup><sub>89f84a1e-75f8-47c5-83b5-bee8e2de4168</sub></sup>|<span style="color:#C60">Medium</span>|Observability|Monitoring log profile captures all the activities (Action, Write, Delete)|<a href="https://docs.ansible.com/ansible/latest/collections/azure/azcollection/azure_rm_monitorlogprofile_module.html">Documentation</a><br/>|
### GCP
Bellow are listed queries related with Ansible GCP:



|            Query             |Severity|Category|Description|Help|
|------------------------------|--------|--------|-----------|----|
|VM With Full Cloud Access<br/><sup><sub>bc20bbc6-0697-4568-9a73-85af1dd97bdd</sub></sup>|<span style="color:#C00">High</span>|Access Control|A VM instance is configured to use the default service account with full access to all Cloud APIs|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html#parameter-service_accounts/scopes">Documentation</a><br/>|
|SQL DB Instance Is Publicly Accessible<br/><sup><sub>7d7054c0-3a52-4e9b-b9ff-cbfe16a2378b</sub></sup>|<span style="color:#C00">High</span>|Access Control|Check if any Cloud SQL instances are publicly accessible.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html">Documentation</a><br/>|
|BigQuery Dataset Is Public<br/><sup><sub>2263b286-2fe9-4747-a0ae-8b4768a2bbd2</sub></sup>|<span style="color:#C00">High</span>|Access Control|BigQuery dataset is anonymously or publicly accessible|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_bigquery_dataset_module.html#parameter-access/special_group">Documentation</a><br/>|
|Cloud Storage Anonymous or Publicly Accessible<br/><sup><sub>086031e1-9d4a-4249-acb3-5bfe4c363db2</sub></sup>|<span style="color:#C00">High</span>|Access Control|Cloud Storage Buckets must not be anonymously or publicly accessible, which means the attribute 'entity' must not be 'allUsers' or 'allAuthenticatedUsers'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_storage_bucket_module.html">Documentation</a><br/>|
|SQL DB Instance Backup Disabled<br/><sup><sub>0c82eae2-aca0-401f-93e4-fb37a0f9e5e8</sub></sup>|<span style="color:#C00">High</span>|Backup|Checks if backup configuration is enabled for all Cloud SQL Database instances|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/backup_configuration/enabled">Documentation</a><br/>|
|High KMS Rotation Period<br/><sup><sub>79f45008-60b3-4a0a-a302-8311fd3701b4</sub></sup>|<span style="color:#C00">High</span>|Encryption|Check if any KMS rotation period surpasses 365 days.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_kms_crypto_key_module.html">Documentation</a><br/>|
|DNSSEC Using RSASHA1<br/><sup><sub>6cf4c3a7-ceb0-4475-8892-3745b84be24a</sub></sup>|<span style="color:#C00">High</span>|Encryption|DNSSEC should not use the RSASHA1 algorithm|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_dns_managed_zone_module.html#return-dnssecConfig/defaultKeySpecs/algorithm">Documentation</a><br/>|
|SQL DB Instance With SSL Disabled<br/><sup><sub>d0f7da39-a2d5-4c78-bb85-4b7f338b3cbb</sub></sup>|<span style="color:#C00">High</span>|Encryption|Cloud SQL Database Instance should have SLL enabled|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/ip_configuration/require_ssl">Documentation</a><br/>|
|PostgreSQL Misconfigured Logging Duration Flag<br/><sup><sub>aed98a2a-e680-497a-8886-277cea0f4514</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|PostgreSQL database 'log_min_duration_statement' flag isn't set to '-1'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|Cluster Labels Disabled<br/><sup><sub>fbe9b2d0-a2b7-47a1-a534-03775f3013f7</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Clusters must be configured with labels, which means the attribute 'resource_labels' must be defined|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Client Certificate Disabled<br/><sup><sub>20180133-a0d0-4745-bfe0-94049fbb12a9</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Clusters must be created with Client Certificate enabled, which means 'master_auth' must have 'client_certificate_config' with the attribute 'issue_client_certificate' equal to true|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|MySQL Instance With Local Infile On<br/><sup><sub>a7b520bb-2509-4fb0-be05-bc38f54c7a4c</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|MySQL Instance should not have Local Infile On|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|Private Cluster Disabled<br/><sup><sub>3b30e3d6-c99b-4318-b38f-b99db74578b5</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Clusters must be created with Private Clusters enabled, meaning the 'private_cluster_config' must be defined and the attributes 'enable_private_endpoint' and 'enable_private_nodes' must be true.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Network Policy Disabled<br/><sup><sub>98e04ca0-34f5-4c74-8fec-d2e611ce2790</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Engine Clusters must have Network Policy enabled, meaning that the attribute 'network_policy.enabled' must be true and the attribute 'addons_config.network_policy_config.disabled' must be false|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Cloud SQL Instance With Cross DB Ownership Chaining On<br/><sup><sub>9e0c33ed-97f3-4ed6-8be9-bcbf3f65439f</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|GCP SQL Instance should not have Cross DB Ownership Chaining On|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|GKE Legacy Authorization Enabled<br/><sup><sub>300a9964-b086-41f7-9378-b6de3ba1c32b</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Engine Clusters must have Legacy Authorization set to disabled, which means the attribute 'legacy_abac.enabled' must be false.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Cluster Master Authentication Disabled<br/><sup><sub>9df7f78f-ebe3-432e-ac3b-b67189c15518</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Engine Clusters must have Master Authentication set to enabled, which means the attribute 'master_auth' must have the subattributes 'username' and 'password' defined and not empty|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|GKE Basic Authentication Enabled<br/><sup><sub>344bf8ab-9308-462b-a6b2-697432e40ba1</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|GCP - Google Kubernetes Engine (GKE) Basic Authentication must be disabled, which means the username and password provided in the master_auth block must be empty|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|IP Aliasing Disabled<br/><sup><sub>ed672a9f-fbf0-44d8-a47d-779501b0db05</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|Kubernetes Clusters must be created with Alias IP ranges enabled, which means the attribute 'ip_allocation_policy' must be defined and the subattribute 'use_ip_aliases' must be set to 'yes'.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Cloud SQL Instance With Contained Database Authentication On<br/><sup><sub>6d34aff3-fdd2-460c-8190-756a3b4969e8</sub></sup>|<span style="color:#C00">High</span>|Insecure Configurations|SQL Instance should not have Contained Database Authentication On|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|GKE Master Authorized Networks Disabled<br/><sup><sub>d43366c5-80b0-45de-bbe8-2338f4ab0a83</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Master authorized networks must be enabled in GKE clusters|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html#parameter-master_authorized_networks_config/enabled">Documentation</a><br/>|
|Compute Instance Is Publicly Accessible<br/><sup><sub>829f1c60-2bab-44c6-8a21-5cd9d39a2c82</sub></sup>|<span style="color:#C00">High</span>|Networking and Firewall|Compute instances shouldn't be accessible from the Internet.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html#parameter-network_interfaces/access_configs">Documentation</a><br/>|
|PostgreSQL Logging Of Temporary Files Disabled<br/><sup><sub>d6fae5b6-ada9-46c0-8b36-3108a2a2f77b</sub></sup>|<span style="color:#C00">High</span>|Observability|PostgreSQL database 'log_temp_files' flag isn't set to '0'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|PostgreSQL Log Connections Disabled<br/><sup><sub>d7a5616f-0a3f-4d43-bc2b-29d1a183e317</sub></sup>|<span style="color:#C00">High</span>|Observability|PostgreSQL database instance should have a 'log_connections' flag with its value set to 'on'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|Stackdriver Logging Disabled<br/><sup><sub>19c9e2a0-fc33-4264-bba1-e3682661e8f7</sub></sup>|<span style="color:#C00">High</span>|Observability|Kubernetes Engine Clusters must have Stackdriver Logging enabled, which means the attribute 'logging_service' must be defined and different from 'none'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Cloud Storage Bucket Versioning Disabled<br/><sup><sub>7814ddda-e758-4a56-8be3-289a81ded929</sub></sup>|<span style="color:#C00">High</span>|Observability|Cloud Storage Bucket should have versioning enabled|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_storage_bucket_module.html#parameter-versioning">Documentation</a><br/>|
|Stackdriver Monitoring Disabled<br/><sup><sub>20dcd953-a8b8-4892-9026-9afa6d05a525</sub></sup>|<span style="color:#C00">High</span>|Observability|Kubernetes Engine Clusters must have Stackdriver Monitoring enabled, which means the attribute 'monitoring_service' must be defined and different than 'none'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html">Documentation</a><br/>|
|Cloud Storage Bucket Logging Not Enabled<br/><sup><sub>507df964-ad97-4035-ab14-94a82eabdfdd</sub></sup>|<span style="color:#C00">High</span>|Observability|Cloud storage bucket with logging not enabled|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_storage_bucket_module.html#parameter-logging">Documentation</a><br/>|
|COS Node Image Not Used<br/><sup><sub>be41f891-96b1-4b9d-b74f-b922a918c778</sub></sup>|<span style="color:#C00">High</span>|Resource Management|The node image should be Container-Optimized OS(COS)|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_node_pool_module.html#parameter-config/image_type">Documentation</a><br/>|
|Node Auto Upgrade Disabled<br/><sup><sub>d6e10477-2e19-4bcd-b8a8-19c65b89ccdf</sub></sup>|<span style="color:#C00">High</span>|Resource Management|Kubernetes nodes must have auto upgrades set to true, which means Node 'auto_upgrade' should be enabled for Kubernetes Clusters|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_node_pool_module.html#parameter-management/auto_upgrade">Documentation</a><br/>|
|Disk Encryption Disabled<br/><sup><sub>092bae86-6105-4802-99d2-99cd7e7431f3</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|VM disks for critical VMs must be encrypted with Customer Supplied Encryption Keys (CSEK) or with Customer-managed encryption keys (CMEK), which means the attribute 'disk_encryption_key' must be defined and its sub attributes 'raw_key' or 'kms_key_self_link' must also be defined|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_disk_module.html">Documentation</a><br/>|
|Google Compute SSL Policy Weak Cipher In Use<br/><sup><sub>b28bcd2f-c309-490e-ab7c-35fc4023eb26</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|This query confirms if Google Compute SSL Policy Weak Chyper Suits is Enabled, to do so we need to check if TLS is TLS_1_2, because other version have Weak Chypers|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_ssl_policy_module.html">Documentation</a><br/>|
|High Google KMS Crypto Key Rotation Period<br/><sup><sub>f9b7086b-deb8-4034-9330-d7fd38f1b8de</sub></sup>|<span style="color:#C60">Medium</span>|Encryption|Make sure Encryption keys changes after 90 days|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_kms_crypto_key_module.html">Documentation</a><br/>|
|Google Container Node Pool Auto Repair Disabled<br/><sup><sub>d58c6f24-3763-4269-9f5b-86b2569a003b</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Verifies if Google Container Node Pool Auto Repair is Enabled. This service periodically checks for failing nodes and repairs them to ensure a smooth running state.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_node_pool_module.html">Documentation</a><br/>|
|OSLogin Is Disabled In VM Instance<br/><sup><sub>66dae697-507b-4aef-be18-eec5bd707f33</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|VM instance should have OSLogin enabled|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html">Documentation</a><br/>|
|GKE Using Default Service Account<br/><sup><sub>dc126833-125a-40fb-905a-ce5f2afde240</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Kubernetes Engine Clusters should not be configured to use the default service account|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_container_cluster_module.html#parameter-node_config/service_account">Documentation</a><br/>|
|Cloud DNS Without DNSSEC<br/><sup><sub>80b15fb1-6207-40f4-a803-6915ae619a03</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|DNSSEC must be enabled for Cloud DNS|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_dns_managed_zone_module.html#return-dnssecConfig/state">Documentation</a><br/>|
|Shielded VM Disabled<br/><sup><sub>18d3a83d-4414-49dc-90ea-f0387b2856cc</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Configurations|Compute instances must be launched with Shielded VM enabled, which means the attribute 'shielded_instance_config' must be defined and its sub attributes 'enable_secure_boot', 'enable_vtpm' and 'enable_integrity_monitoring' must be set to true|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html">Documentation</a><br/>|
|Using Default Service Account<br/><sup><sub>2775e169-e708-42a9-9305-b58aadd2c4dd</sub></sup>|<span style="color:#C60">Medium</span>|Insecure Defaults|Instances must not be configured to use the Default Service Account, that has full access to all Cloud APIs, which means the attribute 'service_account_email' must be defined. Additionally, it must not be empty and must also not be a default Google Compute Engine service account.|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html">Documentation</a><br/>|
|Google Compute Network Using Firewall Rule that Allows All Ports<br/><sup><sub>3602d273-3290-47b2-80fa-720162b1a8af</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Google Compute Network should not use a firewall rule that allows all ports|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_firewall_module.html#parameter-allowed">Documentation</a><br/>|
|SSH Access Is Not Restricted<br/><sup><sub>b2fbf1df-76dd-4d78-a6c0-e538f4a9b016</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Check if Google Firewall allows SSH access (port 22) from the Internet (public CIDR block).|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_firewall_module.html">Documentation</a><br/>|
|RDP Access Is Not Restricted<br/><sup><sub>75418eb9-39ec-465f-913c-6f2b6a80dc77</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Check if the Google compute firewall allows unrestricted RDP access. Allowed ports should not contain RDP port 3389|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_firewall_module.html">Documentation</a><br/>|
|Serial Ports Are Enabled For VM Instances<br/><sup><sub>c6fc6f29-dc04-46b6-99ba-683c01aff350</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Check if serial ports are enabled in Google Compute Engine VM instances|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html">Documentation</a><br/>|
|Google Compute Network Using Default Firewall Rule<br/><sup><sub>29b8224a-60e9-4011-8ac2-7916a659841f</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Google Compute Network should not use default firewall rule|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_firewall_module.html#parameter-name">Documentation</a><br/>|
|IP Forwarding Enabled<br/><sup><sub>11bd3554-cd56-4257-8e25-7aaf30cf8f5f</sub></sup>|<span style="color:#C60">Medium</span>|Networking and Firewall|Instances must not have IP forwarding enabled, which means the attribute 'can_ip_forward' must not be true|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html">Documentation</a><br/>|
|PostgreSQL log_checkpoints Flag Not Set To ON<br/><sup><sub>89afe3f0-4681-4ce3-89ed-896cebd4277c</sub></sup>|<span style="color:#C60">Medium</span>|Observability|PostgreSQL database instance should have a 'log_checkpoints' flag with its value set to 'on'|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|PostgreSQL Misconfigured Log Messages Flag<br/><sup><sub>28a757fc-3d8f-424a-90c0-4233363b2711</sub></sup>|<span style="color:#C60">Medium</span>|Observability|PostgreSQL database 'log_min_messages' flag isn't set to a valid value|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_sql_instance_module.html#parameter-settings/database_flags">Documentation</a><br/>|
|Project-wide SSH Keys Are Enabled In VM Instances<br/><sup><sub>099b4411-d11e-4537-a0fc-146b19762a79</sub></sup>|<span style="color:#C60">Medium</span>|Secret Management|VM Instance should block project-wide SSH keys|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_instance_module.html">Documentation</a><br/>|
|Google Compute Network Using Firewall Rule that Allows Port Range<br/><sup><sub>7289eebd-a477-4064-8ad4-3c044bd70b00</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|Google Compute Network should not use a firewall rule that allows port range|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_firewall_module.html#parameter-allowed">Documentation</a><br/>|
|Google Compute Subnetwork with Private Google Access Disabled<br/><sup><sub>6a4080ae-79bd-42f6-a924-8f534c1c018b</sub></sup>|<span style="color:#CC0">Low</span>|Networking and Firewall|Google Compute Subnetwork should have 'private_ip_google_access' set to yes|<a href="https://docs.ansible.com/ansible/latest/collections/google/cloud/gcp_compute_subnetwork_module.html#parameter-private_ip_google_access">Documentation</a><br/>|
